Improve this Doc View Source

Used for configuring the ARIA attributes injected and managed by ngAria.

    angular.module('myApp', ['ngAria'], function config($ariaProvider) {
      $ariaProvider.config({
        ariaValue: true,
        tabindex: false
      });
    });

## Dependencies

Requires the `ngAria` module to be installed.

## Methods

- ###

  `config(config);`

  Enables/disables various ARIA attributes

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  config | object | object to enable/disable specific ARIA attributes ariaHidden – `{boolean}` – Enables/disables aria-hidden tags ariaChecked – `{boolean}` – Enables/disables aria-checked tags ariaReadonly – `{boolean}` – Enables/disables aria-readonly tags ariaDisabled – `{boolean}` – Enables/disables aria-disabled tags ariaRequired – `{boolean}` – Enables/disables aria-required tags ariaInvalid – `{boolean}` – Enables/disables aria-invalid tags ariaValue – `{boolean}` – Enables/disables aria-valuemin, aria-valuemax and aria-valuenow tags tabindex – `{boolean}` – Enables/disables tabindex tags bindKeydown – `{boolean}` – Enables/disables keyboard event binding on non-interactive elements (such as `div` or `li`) using ng-click, making them more accessible to users of assistive technologies bindRoleForClick – `{boolean}` – Adds role=button to non-interactive elements (such as `div` or `li`) using ng-click, making them more accessible to users of assistive technologies